// -*- C++ -*-
// main handler for TMDs
#include "TMDlib.h"
#include "TMDlibPDFpath.h"


extern int iset ;
int imode, irep;
extern bool first;
bool first = true;
/*!
 * TMDinit 1st part 
 */
void TMDlib::TMDinit(const string name, int irep, int imode ) {

    iset = TMDlib::TMDnumberPDF(name) ;
    cout << " TMDinit: name = " << name << " iset = "<< iset << " irep = " << irep << " imode = " << imode << endl; 
    first=true;
}

/*!
 * TMDinit 2nd part 
 */
void TMDlib::TMDinit(const string name, int irep ) {

    iset = TMDlib::TMDnumberPDF(name) ;
    cout << " TMDinit: name = " << name << " iset = "<< iset << " irep = " << irep <<endl; 
}
/*!
 * TMDinit 3rd part 
 */

void TMDlib::TMDinit(const string name) {

    iset = TMDlib::TMDnumberPDF(name) ;
    irep = 0 ;
    imode = 0;
//    cout << " TMDinit: name = " << name << " iset = "<< iset <<endl; 
    first=true;
}

/*!
 * TMDpdf 1st
 */
vector<double> TMDlib::TMDpdf( double x, double xbar, double kt, double mu) {
    double top,bottom,charm,sea,uval,dval,gluon ;
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      top = 0; 
      gluon  = 0.;

    vector<double> xpq(13);   
    int kf =2212 ; /* kf = 2212 for proton */
    
    if ( x <= TMDgetXmin() ) x=TMDgetXmin();
    if ( x >= TMDgetXmax() ) x=TMDgetXmax();
    if ( mu <= TMDgetQ2min() ) mu=TMDgetQ2min();
    if ( mu >= TMDgetQ2max() ) mu=TMDgetQ2max();
    
    
    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
     }
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
     }    
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    
    xpq[0] = top ;  
    xpq[1] = bottom ;  
    xpq[2] = charm ;  
    xpq[3] = sea ;  
    xpq[4] = sea ;  
    xpq[5] = sea ;  
    xpq[6] = gluon ;  
    xpq[7] = uval+sea ;  
    xpq[8] = dval+sea ;  
    xpq[9] = sea ;  
    xpq[10] = charm ;  
    xpq[11] = bottom ;  
    xpq[12] = top ;  
    return xpq ;
}

/*!
 * TMDpdf 2nd
 */
vector<double> TMDlib::TMDpdf(int kf, double x, double xbar, double kt, double mu) {
    double top,bottom,charm,sea,uval,dval,gluon ;
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      top = 0; 
      gluon  = 0.;

    vector<double> xpq(13);   
    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
     }
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    
    xpq[0] = top ;  
    xpq[1] = bottom ;  
    xpq[2] = charm ;  
    xpq[3] = sea ;  
    xpq[4] = sea ;  
    xpq[5] = sea ;  
    xpq[6] = gluon ;  
    xpq[7] = uval+sea ;  
    xpq[8] = dval+sea ;  
    xpq[9] = sea ;  
    xpq[10] = charm ;  
    xpq[11] = bottom ;  
    xpq[12] = top ;  
    return xpq ;
}

/*!
 * TMDpdf 3rd
 */
void TMDlib::TMDpdf( double x, double xbar, double kt, double mu, vector<double>& xpq) {
    double top,bottom,charm,sea,uval,dval,gluon ;
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      top = 0; 
      gluon  = 0.;
//    vector<double> xpq(13);   
    int kf =2212 ; /* kf = 2212 for proton */
    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
     }
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    
    if ( kf == 2212 ) {
       xpq[0] = top ;  
       xpq[1] = bottom ;  
       xpq[2] = charm ;  
       xpq[3] = sea ;  
       xpq[4] = sea ;  
       xpq[5] = sea ;  
       xpq[6] = gluon ;  
       xpq[7] = dval+sea ;  
       xpq[8] = uval+sea ;  
       xpq[9] = sea ;  
       xpq[10] = charm ;  
       xpq[11] = bottom ;  
       xpq[12] = top ;  
    }
    else if ( kf == -2212 ){
       xpq[0] = top ;  
       xpq[1] = bottom ;  
       xpq[2] = charm ;  
       xpq[3] = sea ;  
       xpq[4] = uval+sea ;  
       xpq[5] = dval+sea ;  
       xpq[6] = gluon ;  
       xpq[7] = sea ;  
       xpq[8] = sea ;  
       xpq[9] = sea ;  
       xpq[10] = charm ;  
       xpq[11] = bottom ;  
       xpq[12] = top ;  
    }
}

/*!
 * TMDpdf 4th
 */
void TMDlib::TMDpdf(int kf, double x, double xbar, double kt, double mu, vector<double>& xpq) {
    double top,bottom,charm,sea,uval,dval,gluon ;
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      top = 0; 
      gluon  = 0.;
//    vector<double> xpq(13);   
    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
     }
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    
    if ( kf == 2212 ) {
       xpq[0] = top ;  
       xpq[1] = bottom ;  
       xpq[2] = charm ;  
       xpq[3] = sea ;  
       xpq[4] = sea ;  
       xpq[5] = sea ;  
       xpq[6] = gluon ;  
       xpq[7] = dval+sea ;  
       xpq[8] = uval+sea ;  
       xpq[9] = sea ;  
       xpq[10] = charm ;  
       xpq[11] = bottom ;  
       xpq[12] = top ;  
    }
    else if ( kf == -2212 ){
       xpq[0] = top ;  
       xpq[1] = bottom ;  
       xpq[2] = charm ;  
       xpq[3] = sea ;  
       xpq[4] = uval+sea ;  
       xpq[5] = dval+sea ;  
       xpq[6] = gluon ;  
       xpq[7] = sea ;  
       xpq[8] = sea ;  
       xpq[9] = sea ;  
       xpq[10] = charm ;  
       xpq[11] = bottom ;  
       xpq[12] = top ;  
    }
    else { cout << " TMDpdf: wronf flavor code kf = " << kf << endl; }
}

/*!
 * TMDpdf 5th
 */
void TMDlib::TMDpdf( double x, double xbar, double kt, double mu, double& uval, double& dval, double& sea, double& charm, double& bottom, double& gluon) {

int kf =2212 ; /* kf = 2212 for proton */
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      gluon  = 0.;

    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      } 
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
      }   
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
      }
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }

//    cout << " TMDpdf: x, xbar, kt, mu " << x << " " << xbar << " " << kt << " " << mu << endl;

}

/*!
 * TMDpdf 6th
 */
void TMDlib::TMDpdf(int kf, double x, double xbar, double kt, double mu, double& uval, double& dval, double& sea, double& charm, double& bottom, double& gluon) {
    //Initialize output
      uval   = 0.;
      dval   = 0.;
      sea    = 0.;
      charm  = 0.;
      bottom = 0.;
      gluon  = 0.;

    if ( iset >= 101000 && iset <=101320 ) {
      ccfmuPDF(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
      } 
    else if ( iset >= 111000 && iset <=111320 ) {
      ccfmiPDF(kf,x,mu, uval, dval, sea, charm, bottom, gluon ) ;
      }     
    else if ( iset == 200001  ) {
      gbwuPDFlight(x,kt, gluon) ;
      } 
    else if ( iset == 200002  ) {
      gbwuPDFcharm(x,kt, gluon) ;
      } 
    else if ( iset >= 300001 && iset <= 300003 ) {
      sbrsPDF(irep, imode, x, kt, mu, uval, dval, sea, charm) ;
     }
    else if ( iset >= 400000 && iset <= 400004 ) {
      ksPDF(x, kt, mu, uval, dval, sea, charm, bottom, gluon ) ;
     }
    else if ( iset >= 500001 && iset <= 500004 ) {
      tmd_ME(kf,x,kt,mu, uval, dval, sea, charm, bottom, gluon ) ;
     }

//    cout << " TMDpdf: x, xbar, kt, mu " << x << " " << xbar << " " << kt << " " << mu << endl;

}



